Struct sp1_core::alu::add_sub::AddSubCols
source · #[repr(C)]pub struct AddSubCols<T> {
pub shard: T,
pub channel: T,
pub nonce: T,
pub add_operation: AddOperation<T>,
pub operand_1: Word<T>,
pub operand_2: Word<T>,
pub is_add: T,
pub is_sub: T,
}Expand description
The column layout for the chip.
Fields
shard: TThe shard number, used for byte lookup table.
channel: TThe channel number, used for byte lookup table.
nonce: TThe nonce of the operation.
add_operation: AddOperation<T>Instance of AddOperation to handle addition logic in AddSubChip’s ALU operations.
It’s result will be a for the add operation and b for the sub operation.
operand_1: Word<T>The first input operand. This will be b for add operations and c for sub operations.
operand_2: Word<T>The second input operand. This will be c for both operations.
is_add: TBoolean to indicate whether the row is for an add operation.
is_sub: TBoolean to indicate whether the row is for a sub operation.