Struct sp1_core::alu::sr::ShiftRightCols
source · #[repr(C)]pub struct ShiftRightCols<T> {Show 17 fields
pub shard: T,
pub channel: T,
pub nonce: T,
pub a: Word<T>,
pub b: Word<T>,
pub c: Word<T>,
pub shift_by_n_bits: [T; 8],
pub shift_by_n_bytes: [T; 4],
pub byte_shift_result: [T; 8],
pub bit_shift_result: [T; 8],
pub shr_carry_output_carry: [T; 8],
pub shr_carry_output_shifted_byte: [T; 8],
pub b_msb: T,
pub c_least_sig_byte: [T; 8],
pub is_srl: T,
pub is_sra: T,
pub is_real: T,
}Expand description
The column layout for the chip.
Fields
shard: TThe shard number, used for byte lookup table.
channel: TThe channel number, used for byte lookup table.
nonce: TThe nonce of the operation.
a: Word<T>The output operand.
b: Word<T>The first input operand.
c: Word<T>The second input operand.
shift_by_n_bits: [T; 8]A boolean array whose ith element indicates whether num_bits_to_shift = i.
shift_by_n_bytes: [T; 4]A boolean array whose ith element indicates whether num_bytes_to_shift = i.
byte_shift_result: [T; 8]The result of “byte-shifting” the input operand b by num_bytes_to_shift.
bit_shift_result: [T; 8]The result of “bit-shifting” the byte-shifted input by num_bits_to_shift.
shr_carry_output_carry: [T; 8]The carry output of shrcarry on each byte of byte_shift_result.
shr_carry_output_shifted_byte: [T; 8]The shift byte output of shrcarry on each byte of byte_shift_result.
b_msb: TThe most significant bit of b.
c_least_sig_byte: [T; 8]The least significant byte of c. Used to verify shift_by_n_bits and shift_by_n_bytes.
is_srl: TIf the opcode is SRL.
is_sra: TIf the opcode is SRA.
is_real: TSelector to know whether this row is enabled.