Struct sp1_core::syscall::precompiles::edwards::EdDecompressCols
source · #[repr(C)]pub struct EdDecompressCols<T> {
pub is_real: T,
pub shard: T,
pub channel: T,
pub clk: T,
pub nonce: T,
pub ptr: T,
pub sign: T,
pub x_access: GenericArray<MemoryWriteCols<T>, <Ed25519BaseField as NumWords>::WordsFieldElement>,
pub y_access: GenericArray<MemoryReadCols<T>, <Ed25519BaseField as NumWords>::WordsFieldElement>,
/* private fields */
}Expand description
A set of columns to compute EdDecompress given a pointer to a 16 word slice formatted as such:
The 31st byte of the slice is the sign bit. The second half of the slice is the 255-bit
compressed Y (without sign bit).
After EdDecompress, the first 32 bytes of the slice are overwritten with the decompressed X.
Fields
is_real: Tshard: Tchannel: Tclk: Tnonce: Tptr: Tsign: Tx_access: GenericArray<MemoryWriteCols<T>, <Ed25519BaseField as NumWords>::WordsFieldElement>y_access: GenericArray<MemoryReadCols<T>, <Ed25519BaseField as NumWords>::WordsFieldElement>Implementations
sourceimpl<F: PrimeField32> EdDecompressCols<F>
impl<F: PrimeField32> EdDecompressCols<F>
pub fn populate<P: FieldParameters, E: EdwardsParameters>( &mut self, event: EdDecompressEvent, record: &mut ExecutionRecord, )
sourceimpl<V: Copy> EdDecompressCols<V>
impl<V: Copy> EdDecompressCols<V>
pub fn eval<AB: SP1AirBuilder<Var = V>, P: FieldParameters, E: EdwardsParameters>( &self, builder: &mut AB, )