Enum sp1_core::syscall::precompiles::weierstrass::SignChoiceRule
source · pub enum SignChoiceRule {
LeastSignificantBit,
Lexicographic,
}Expand description
The convention for choosing the decompressed y value given a sign bit.
Variants
LeastSignificantBit
Lease significant bit convention.
In this convention, the sign_bit matches the pairty of the y value. This is the
convention used in the ECDSA signature scheme, for example, in the secp256k1 curve.
Lexicographic
Lexicographic convention.
In this convention, the sign_bit corresponds to whether the y value is larger than its
negative counterpart with respect to the embedding of ptime field elements as integers.
This onvention used in the BLS signature scheme, for example, in the BLS12-381 curve.